@@ -1,7 +1,8 @@
 from django.core.management.base import BaseCommand, CommandError
 from django.contrib.auth import get_user_model
 from djangoldp.models import Model
-from djangoldp_community.models import Community, CommunityMember
+from djangoldp_circle.models import Circle
+from djangoldp_community.models import Community, CommunityMember, CommunityCircle
 
 class Command(BaseCommand):
   help = 'Create a community and append all local users to it'
@@ -14,5 +15,8 @@ class Command(BaseCommand):
     for user in get_user_model().objects.all():
       if(not Model.is_external(user)):
         CommunityMember.objects.get_or_create(community=community[0], user=user)
+    for circle in Circle.objects.all():
+      if(not Model.is_external(circle)) and not hasattr(circle, 'community'):
+        CommunityCircle.objects.get_or_create(community=community[0], circle=circle)
 
     self.stdout.write(self.style.SUCCESS('Successful created community'))
