@@ -202,10 +202,13 @@ def pre_create_account(sender, instance, **kwargs):
 
 @receiver(post_save, sender=Circle)
 def pre_save_circle_relation(sender, instance, **kwargs):
-    if instance.community:
-        if instance.community.community:
-            instance.community.circle = instance
-            instance.community.save()
+    try:
+        if instance.community:
+            if instance.community.community:
+                instance.community.circle = instance
+                instance.community.save()
+    except (Community.DoesNotExist, CommunityCircle.DoesNotExist):
+        pass
 
 @receiver(post_save, sender=Community)
 def create_community_profile(instance, created, **kwargs):
